@@ -2,7 +2,7 @@
  * @file   jconf.h
  * 
  * <JA>
- * @brief  Jconf ¤Τ
+ * @brief  Jconf 構造体の定義
  *
  * </JA>
  * 
@@ -176,6 +176,10 @@ typedef struct __jconf_am__ {
      * CMN: MAP weight for initial cepstral mean on (-cmnmapweight)
      */
     float cmn_map_weight;
+    /**
+     * CMN: TRUE if static CMN/CVN only applies CVN at file input
+     */
+    boolean cmn_static_cvn_only;
 
   } analysis;
 
@@ -237,7 +241,10 @@ typedef struct __jconf_am__ {
     char *output_bfile;		/* b vector file for output layer */
     char *priorfile;		/* state prior file */
     float prior_factor;		/* state prior factor */
+    boolean prior_factor_log10nize; /* TRUE when requires log10nize state priors */
     int batchsize;		/* batch size */
+    int num_threads;		/* number of threads */
+    char *cuda_mode; /* mode string of CUDA */
   } dnn;
 
   /* pointer to next instance */
@@ -981,6 +988,33 @@ typedef struct __Jconf__ {
      */
     float gmm_downtrigger_thres;
 #endif
+
+#ifdef HAVE_LIBFVAD
+    /**
+     * (LIBFVAD) mode value for libfvad.  -1 means disabled.  >0
+     * values will be passed to fvad_set_mode().  values values are
+     * from 0 to 3.  Smaller value indicates moderate detection: less
+     * aggressive, put focus on picking up all possible speech, likely
+     * to accepting speech-like noise part.  Larger value indicates
+     * very aggressive detection, putting focus on accepting truly
+     * speech only part, aggressively dropping amiguous part.
+     */
+    int fvad_mode;
+
+    /**
+     * (LIBFVAD) number of frames for smoothing.  Last N frames (where 1
+     * frame is fixed to 10ms) value are averaged to get stational VAD.
+     */
+    int fvad_smoothnum;
+
+    /**
+     * (LIBFVAD) speech likelihood threshold value to finaly detect
+     * speech trigger.  Value should be between 0.0 and 1.0.  Typical
+     * value is 0.5. 
+     */
+    float fvad_thres;
+#endif /* HAVE_LIBFVAD */
+    
   } detect;
 
   /**
